@@ -228,6 +228,9 @@ Options:
   --release-heuristic log|changelog
          Select heuristic used to determine if a package has been released.
          (default: changelog)
+  --date <date>
+         Use the specified date in the changelog entry being edited.
+         The date should be in RFC 5322 format.
   --help, -h
          Display this help message and exit
   --version
@@ -268,6 +271,7 @@ my $opt_allow_lower           = '';
 my $opt_auto_nmu              = 1;
 my $opt_force_save_on_release = 1;
 my $opt_vendor                = undef;
+my $opt_date                  = undef;
 
 # Next, read configuration files and then command line
 # The next stuff is boilerplate
@@ -417,6 +421,7 @@ GetOptions(
     "auto-nmu!"              => \$opt_auto_nmu,
     "force-save-on-release!" => \$opt_force_save_on_release,
     "vendor=s"               => \$opt_vendor,
+    "date=s"                 => \$opt_date,
   )
   or die
 "Usage: $progname [options] [changelog entry]\nRun $progname --help for more details\n";
@@ -1042,8 +1047,22 @@ if (@ARGV and !$TEXT) {
 # Get the date
 my $DATE;
 {
-    local $ENV{TZ} = $opt_tz if $opt_tz;
-    $DATE = strftime "%a, %d %b %Y %T %z", localtime();
+    my $date_rfc5322
+      = '^(((Mon|Tue|Wed|Thu|Fri|Sat|Sun))[,]?\s[0-9]{1,2})\s(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)\s([0-9]{4})\s([0-9]{2}):([0-9]{2})(:([0-9]{2}))?\s([\+|\-][0-9]{4})$';
+
+    if (defined $opt_date) {
+        if ($opt_date =~ /$date_rfc5322/) {
+            $DATE = $opt_date;
+        } else {
+            my $example_date = strftime "%a, %d %b %Y %T %z", localtime();
+            fatal(
+"Date '$opt_date' is not in RFC 5322 format. Example: $example_date"
+            );
+        }
+    } else {
+        local $ENV{TZ} = $opt_tz if $opt_tz;
+        $DATE = strftime "%a, %d %b %Y %T %z", localtime();
+    }
 }
 
 if ($opt_news && !$opt_i && !$opt_a) {
